;(function () {
    var bridge = window.WebViewJavascriptBridge;

    if (!bridge) {
        console.log('***** Bridge has not initialized *****');
        return
    }

    //WebViewJavascriptBridge中相关函数
    var send = bridge.send;
    var callHandler = bridge.callHandler;
    var callHandlerExt = bridge.callHandlerExt;
    var registerHandler = bridge.registerHandler;

    var yibanPrivate = {
        getSuccessCallBack: function (obj) {
            if (yibanPrivate.isEmpty(obj)) {
                return null;
            }
            var method = obj.success;
            if ((method == null) || (typeof method == 'undefined') || !(method instanceof Function)) {
                return null;
            } else {
                return method;
            }
        },
        getFailCallBack: function (obj) {
            if (yibanPrivate.isEmpty(obj)) {
                return null;
            }
            var method = obj.fail;
            if ((method == null) || (typeof method == 'undefined') || !(method instanceof Function)) {
                return null;
            } else {
                return method;
            }
        },
        isEmpty: function (obj) {
            if (typeof obj === 'undefined' || obj == null || obj === '') {
                return true;
            } else {
                return false;
            }
        },
        isSupportMethod: function (methodName) {
            if (yibanPrivate.isEmpty(yiban)) {
                return false;
            }
            return (typeof yiban.prototype[methodName] === 'function');
        }
    };

    var yiban = function () {
    };

    /**
     * @api {接口} yiban.canIUse canIUse
     * @apiGroup yiban
     * @apiDescription 支持可用方法
     *
     * @apiSuccessExample 使用示例
     * yiban.canIUse("back");
     *
     */
    yiban.prototype.canIUse = function (method) {
        if (yibanPrivate.isEmpty(method)) {
            return false;
        }
        if (method.startsWith("yiban.")) {
            method = method.replace('yiban.', '');
        }
        return yibanPrivate.isSupportMethod(method);
    };

    /**
     * @api {接口} yiban.back back
     * @apiGroup yiban
     * @apiDescription 页面返回
     *
     * @apiSuccessExample 使用示例
     * yiban.back();
     *
     */
    yiban.prototype.back = function () {
        callHandler('back', [], null);
    };

    /**
     * @api {接口} yiban.close close
     * @apiGroup yiban
     * @apiDescription 页面关闭
     *
     * @apiSuccessExample 使用示例
     * yiban.close();
     *
     */
    yiban.prototype.close = function () {
        callHandler("close", [], null);
    };

    /**
     * @api {接口} yiban.refresh refresh
     * @apiGroup yiban
     * @apiDescription 页面刷新
     *
     * @apiSuccessExample 使用示例
     * yiban.refresh();
     *
     */
    yiban.prototype.refresh = function () {
        callHandler("refresh", [], null);
    };

    /**
     * @api {接口} yiban.share share
     * @apiGroup yiban
     * @apiDescription 分享链接
     *
     * @apiSuccessExample 使用示例
     yiban.share({
      icon:'http://www.yiban.cn/favicon.ico', //图标 可为空
      title:'易班网', //标题
      content:'欢迎来到易班网', //内容
      link:'http://www.yiban.cn', //链接
    });
     *
     */
    yiban.prototype.share = function(obj) {
        var success = yibanPrivate.getSuccessCallBack(obj);
        var fail = yibanPrivate.getFailCallBack(obj);
        callHandlerExt("share", [obj], success, fail);
    };

    /**
     * @api {接口} yiban.showTip showTip
     * @apiGroup yiban
     * @apiParam {tip} 提示文本
     * @apiDescription 显示提示
     *
     * @apiSuccessExample 使用示例
     * yiban.showTip("测试");
     *
     */
    yiban.prototype.showTip = function (tip) {
        callHandler("showTip", [tip], null);
    };

    /**
     * @api {接口} yiban.showError showError
     * @apiGroup yiban
     * @apiParam {tip} 提示文本
     * @apiDescription 显示错误提示
     *
     * @apiSuccessExample 使用示例
     * yiban.showTip("测试");
     *
     */
    yiban.prototype.showError = function (error) {
        callHandler("showError", [error], null);
    };

    /**
     * @api {接口} yiban.setNavTitle setNavTitle
     * @apiGroup yiban
     * @apiDescription 设置导航栏中间标题
     *
     * @apiParam {String} text 导航栏标题
     *
     * @apiSuccessExample 使用示例
     * yiban.setNavTitle('标题1');
     *
     */
    yiban.prototype.setNavTitle = function (text) {
        callHandler("setNavTitle", [text], null);
    };

    /**
     * @api {接口} yiban.setNavHeader setNavHeader
     * @apiGroup yiban
     * @apiDescription 设置导航栏左边按钮（多个），右边按钮（多个），中间标题
     *
     * @apiParam {Object} config 导航栏配置信息
     *
     * @apiSuccessExample 使用示例
     * var config = {
        title: '网页标题234', //网页标题
        showShareButton: false, //是否显示分享按钮 默认是true
        statusStyle: 'black',//状态栏样式, 只支持 black, white
        backgroundColor:'0000ff',//导航栏背景色
        tintColor:'ff0000',//标题和返回按钮颜色
        bottomLineColor:'ff0000',//底部线条颜色，如果传空表示隐藏，传值展示相应颜色，key都不带表示保存默认不变
        hideNavBar:false, //是否隐藏导航栏, 默认false
        transparentNavBar:false, //隐藏导航栏是否透明, 默认false
        pageOrientation:'landscape' //页面横屏竖屏  支持: portrait | landscape  默认 portrait
      };

     * yiban.setNavHeader(config);
     *
     */
    yiban.prototype.setNavHeader = function (config) {
        callHandler("setNavHeader", [config], null);
    };

    /**
     * @api {接口} yiban.showNavBar showNavBar
     * @apiGroup yiban
     * @apiDescription 显示导航栏
     *
     * @apiSuccessExample 使用示例
     * yiban.showNavBar();
     *
     */
    yiban.prototype.showNavBar = function () {
        callHandler("showNavBar", [], null);
    };

    /**
     * @api {接口} yiban.hideNavBar hideNavBar
     * @apiGroup yiban
     * @apiDescription 隐藏导航栏
     *
     * @apiSuccessExample 使用示例
     * yiban.hideNavBar(false);
     *
     */
    yiban.prototype.hideNavBar = function () {
        callHandler("hideNavBar", [], null);
    };

    /**
     * @api {接口} yiban.transparentNavBar transparentNavBar
     * @apiGroup yiban
     * @apiDescription 设置导航栏透明
     *
     * @apiSuccessExample 使用示例
     * yiban.transparentNavBar();
     *
     */
    yiban.prototype.transparentNavBar = function () {
        callHandler("transparentNavBar", [], null);
    };

    /**
     * @api {接口} yiban.untransparentNavBar untransparentNavBar
     * @apiGroup yiban
     * @apiDescription 设置导航栏不透明
     *
     * @apiSuccessExample 使用示例
     * yiban.untransparentNavBar();
     *
     */
    yiban.prototype.untransparentNavBar = function () {
        callHandler("untransparentNavBar", [], null);
    };

    /**
     * @api {接口} yiban.getUUID getUUID
     * @apiGroup yiban
     * @apiDescription 获取设备的UUID
     *
     * @apiParam {function} callback 回调方法，返回设备的UUID
     *
     * @apiSuccessExample 使用示例
     * yiban.getUUID(function(uuid){
       console.log('UUID : ' + uuid);
     });
     *
     */
    yiban.prototype.getUUID = function (callback) {
        callHandler("getUUID", [], callback);
    };

    /**
     * @api {接口} yiban.getDeviceInfo getDeviceInfo
     * @apiGroup yiban
     * @apiDescription 获取设备信息
     *
     * @apiParam {function} callback 回调方法，返回设备信息
     *
     * @apiSuccessExample 使用示例
     * yiban.getDeviceInfo(function(result){
       console.log('机器型号 : ' + result.deviceModel + '系统版本 : ' + result.systemVersion + 'APP版本 : ' + result.appVersion);
     });
     *
     */
    yiban.prototype.getDeviceInfo = function (callback) {
        callHandler("getDeviceInfo", [], callback);
    };

    /**
     * @api {接口} yiban.scan scan
     * @apiGroup yiban
     * @apiDescription 打开扫描页面进行扫码，当扫描到数据后把结果返回
     * @apiParam {Object}  扫描调用参数
     *  {
        success: //成功回调函数-可选
        fail: //失败回调函数-可选
      };
     *
     * @apiSuccessExample 使用示例
     需要回调:
     yiban.scan({
    success:function(result){
        yiban.showTip(result);
    },
    fail:function(error){
        yiban.showError(error);
    }});
     无回调仅打开扫描页面：
     yiban.scan();
     */
    yiban.prototype.scan = function (obj) {
        var success = yibanPrivate.getSuccessCallBack(obj);
        var fail = yibanPrivate.getFailCallBack(obj);
        callHandlerExt("scan", [obj], success, fail);
    };

    /**
     * @api {接口} yiban.viewVRImage viewVRImage
     * @apiGroup yiban
     * @apiDescription 查看VR图片
     * @apiParam {string} vrImageUrl VRImage 地址
     *
     * @apiSuccessExample 使用示例
     需要回调:
     yiban.viewVRImage('http://res.yikevr.com/vr/10/index.jpg');

     */

    yiban.prototype.viewVRImage = function (vrurl) {
        callHandler("viewVRImage", [vrurl]);
    };

    /**
     * @api {接口} yiban.viewVRVideo viewVRVideo
     * @apiGroup yiban
     * @apiDescription 查看VR视频
     * @apiParam {string} vrVideoUrl VRVideo 地址
     *
     * @apiSuccessExample 使用示例
     需要回调:
     yiban.viewVRVideo('http://res.yikevr.com/vr/5/index.mp4');

     */

    yiban.prototype.viewVRVideo = function (vrurl) {
        callHandler("viewVRVideo", [vrurl]);
    };

    /**
     * @api {接口} yiban.launchWXMiniProgram launchWXMiniProgram
     * @apiGroup yiban
     * @apiDescription 打开微信小程序
     * @apiParam {Object} 调用参数
     *  {
        userName:"gh_xxxx",  //填小程序原始id
        path:"test?a=1", //拉起小程序页面的可带参路径，不填默认拉起小程序首页，对于小游戏，可以只传入 query 部分，来实现传参效果，如：传入 "?foo=bar"。
        type:0 // 0: 正式版, 1: 开发版, 2: 预览版
      };
     *
     * @apiSuccessExample 使用示例
     需要回调:
     yiban.launchWXMiniProgram({userName:"gh_xxxx", path:"test?a=1"});
     */

    yiban.prototype.launchWXMiniProgram = function (obj) {
        callHandler("launchWXMiniProgram", [obj]);
    };

    /**
     * @api {接口} yiban.previewImages previewImages
     * @apiGroup yiban
     * @apiDescription 预览图片
     *
     * @apiParam {string[]} images 图片数组
     * @apiParam {int} index 显示图片的index 默认从 0 开始
     *
     * @apiSuccessExample 使用示例
     * yiban.previewImages(['http://www.yiban.cn/upload/system/202008/200828104801773089.png', 'http://www.yiban.cn/upload/system/202008/200824132654662518.jpg'], 1);
     *
     */
    yiban.prototype.previewImages = function (images, index) {
        callHandler("previewImages", [images, index]);
    };

    /**
     * @api {接口} yiban.getLocation getLocation
     * @apiGroup yiban
     * @apiDescription 获取当前的坐标
     * @apiParam {Object}  调用参数
     *  {
        success: //成功回调函数-可选
        fail: //失败回调函数-可选
      };
     *
     * @apiSuccessExample 使用示例
     yiban.getLocation({
    success:function(locationInfo){
        yiban.showTip(JSON.stringify(locationInfo));
    },
    fail:function(error){
        yiban.showError(error);
    }});

     */
    yiban.prototype.getLocation = function (obj) {
        var success = yibanPrivate.getSuccessCallBack(obj);
        var fail = yibanPrivate.getFailCallBack(obj);
        callHandlerExt("getLocation", [obj], success, fail);
    };

    /**
     * @api {接口} yiban.startIBeaconDiscovery startIBeaconDiscovery
     * @apiGroup yiban
     * @apiDescription 开启蓝牙设备发现
     * @apiParam {Object}  调用参数
     *  {
        success: //成功回调函数-可选
        fail: //失败回调函数-可选
        uuids: [] // iBeacon 设备广播的 uuid 列表 必填参数
      };
     *
     * @apiSuccessExample 使用示例
     yiban.startIBeaconDiscovery({
    success:function(res){
        yiban.showTip(JSON.stringify(res));
    },
    fail:function(error){
        yiban.showTip(JSON.stringify(error));
    },
    uuids:[""]
    });

     * @errorCode 错误参数对照列表
     错误码 错误消息
     0     正常
     11000 系统或设备不支持
     11001 蓝牙服务不可用
     11002 位置服务不可用
     11003 已经开始搜索
     11004 还未开始搜索
     11005 系统错误
     11006 参数不正确
     */
    yiban.prototype.startIBeaconDiscovery = function (obj) {
        var success = yibanPrivate.getSuccessCallBack(obj);
        var fail = yibanPrivate.getFailCallBack(obj);
        callHandlerExt("startIBeaconDiscovery", [obj], success, fail);
    };

    /**
     * @api {接口} yiban.stopIBeaconDiscovery stopIBeaconDiscovery
     * @apiGroup yiban
     * @apiDescription 关闭蓝牙设备发现
     *
     * @apiSuccessExample 使用示例
     yiban.stopIBeaconDiscovery();

     */

    yiban.prototype.stopIBeaconDiscovery = function (obj) {
        callHandler("stopIBeaconDiscovery", []);
    };

    /**
     * @api {接口} yiban.onIBeaconUpdate onIBeaconUpdate
     * @apiGroup yiban
     * @apiDescription 监听 iBeacon 设备更新事件，仅能注册一个监听
     *
     * @apiSuccessExample 使用示例
     yiban.onIBeaconUpdate();

     */

    yiban.prototype.onIBeaconUpdate = function (callback) {
        window.yiban.iBeaconUpdateCallback = callback;
        callHandler("onIBeaconUpdate", []);
    };

    /**
     * @api {接口} yiban.offIBeaconUpdate offIBeaconUpdate
     * @apiGroup yiban
     * @apiDescription 监听 iBeacon 设备更新事件，仅能注册一个监听
     *
     * @apiSuccessExample 使用示例
     yiban.offIBeaconUpdate();

     */
    yiban.prototype.offIBeaconUpdate = function () {
        window.yiban.iBeaconUpdateCallback = null;
        callHandler("offIBeaconUpdate", []);
    };

    /**
     * @api {接口} yiban.getIBeacons getIBeacons
     * @apiGroup yiban
     * @apiDescription 获取所有已搜索到的 iBeacon 设备
     * @apiParam {Object}  调用参数
     *  {
        success: //成功回调函数-可选
        fail: //失败回调函数-可选
      };
     *
     * @apiSuccessExample 使用示例
     yiban.getIBeacons({
    success:function(res){
        yiban.showTip(JSON.stringify(res));
    },
    fail:function(error){
        yiban.showTip(JSON.stringify(error));
    }});

     */
    yiban.prototype.getIBeacons = function (obj) {
        var success = yibanPrivate.getSuccessCallBack(obj);
        var fail = yibanPrivate.getFailCallBack(obj);
        callHandlerExt("getIBeacons", [obj], success, fail);
    };

    /**
     * 创建并发送YibanDeviceReady事件
     */
    yiban.prototype.dispatchDeviceReadyEvent = function () {
        var event = window.document.createEvent('Events');
        event.initEvent('YibanDeviceReady', false, false);
        window.document.dispatchEvent(event);
    };

    /**
     * getWebExtentData
     * @returns {{}}
     */
    yiban.prototype.getWebExtentData = function () {
        var meta = document.getElementsByTagName("meta");
        var data = {};
        data.title = document.title;
        for (i = 0; i < meta.length; i++) {
            if (typeof meta[i].name != "undefined" && meta[i].name.toLowerCase() == "description") {
                data.description = meta[i].content;
                break;
            }
        }
        var link = document.getElementsByTagName("link");
        for (i = 0; i < link.length; i++) {
            if (typeof link[i].rel != "undefined" && link[i].rel.toLowerCase().indexOf("icon") != -1) {
                var img = new Image();
                img.src = link[i].href;
                data.icon = img.src;
                break;
            }
        }
        return data;
    };

    /**
     * getYiBanExtentData
     * @returns {{}}
     */
    yiban.prototype.getYiBanExtentData = function () {
        var meta = document.getElementsByTagName("meta");
        var title = document.getElementById("share-title") != undefined ? document.getElementById("share-title").value : document.title;
        var logo = document.getElementById("share-logo") != undefined ? document.getElementById("share-logo").value : "";
        var description = document.getElementById("share-intro") != undefined ? document.getElementById("share-intro").value : "";
        if(description == "") {
            for (i = 0; i < meta.length; i++) {
                if (typeof meta[i].name != "undefined" && meta[i].name.toLowerCase() == "description") {
                    description = meta[i].content;
                    break;
                }
            }
        }

        var navColor = document.getElementById("theme-color") != undefined ? document.getElementById("theme-color").value : "";
        var yibanMobile = document.getElementsByName("yibanmobile")[0] != undefined ? document.getElementsByName("yibanmobile")[0].content : "";
        var data = {};
        data.title = title;
        data.description = description;
        data.icon = logo;
        data.navColor = navColor;
        data.yibanMobile = yibanMobile;
        return data;
    };

    /**
       * @api {接口} yiban.openWebView openWebView
       * @apiGroup yiban
       * @apiDescription 打开一个新网页
       *
       * @apiSuccessExample 使用示例
        yiban.openWebView({
          url:'http://www.yiban.cn/', //网页地址
          title:'易班网', //默认标题
        });
       *
       */
     yiban.prototype.openWebView = function(obj) {
        callHandlerExt("openWebView", [obj], null, null);
     };


     /**
        * @api {接口} yiban.onShared onShared
        * @apiGroup yiban
        * @apiDescription 分享回调, 当用户点击分享框某一项后 会触发该js回调
        * 分享渠道值: wechat: 微信聊天 wechat-timeline: 微信朋友圈 qq: QQ聊天 qq-qzone: QQ空间 copy-link: 复制链接
        *
        * @apiSuccessExample 使用示例
          yiban.onShared(function(result){
            console.log('分享渠道 : ' + result.channel + '分享地址 : ' + result.url);
          });
        *
        */
      yiban.prototype.onShared = function(callback) {
          window.yiban.onSharedCallback = callback;
      };




    //初始化iBeaconUpdateCallback
    yiban.prototype.iBeaconUpdateCallback = null;

    //设置全局yiban变量
    window.yiban = new yiban();
    //yiban.js注册完成通知Native端
    callHandler('YiBanJSInjected', 'YiBan.js Is Injected', null);
    console.log('***** YiBan JS File Is Injected *****');
})();